Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Generator ¶
type Generator struct {
AnyCharacter bool
Digit bool
Interval string
Base64 bool
Hex bool
Ulid bool
UlidAsUuid bool
Uuid bool
Uuid7 bool
Lower bool
Upper bool
Prefix string
Suffix string
Separator string
WithLineFeed bool
}
func (*Generator) GenInterval ¶
GenInterval works in a fundamentally different way than Gen since the string length can be variable, so we can't reuse the same (fixed-length) buffer for the results and possible encoding (base64, hex).
Click to show internal directories.
Click to hide internal directories.